@@ -142,10 +142,6 @@ class CreateMetricOperator(BaseOperator):
             existing_metric["thresholds"] = metric["thresholds"]
             existing_metric["notificationChannels"] = metric.get("notificationChannels", [])
             existing_metric["scheduleFrequency"] = metric["scheduleFrequency"]
-            if not is_freshness_metric:
-                existing_metric["lookbackType"] = metric["lookbackType"]
-                existing_metric["lookback"] = metric["lookback"]
-                existing_metric["grainSeconds"] = metric["grainSeconds"]
             return existing_metric
 
     def _is_freshness_metric(self, metric_name):
